bayespy.inference.vmp.nodes.multinomial.MultinomialDistribution.compute_fixed_moments_and_f
===========================================================================================

.. currentmodule:: bayespy.inference.vmp.nodes.multinomial

.. automethod:: MultinomialDistribution.compute_fixed_moments_and_f